==> james-project-3.7.6-source-release.zip: james-project/mailbox/store/src/main/java/org/apache/james/mailbox/store/FakeAuthenticator.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.mailbox.store;

import java.util.HashMap;
import java.util.Map;

import org.apache.james.core.Username;
import org.apache.james.mailbox.Authenticator;

public class FakeAuthenticator implements Authenticator {

    private final Map<String, String> users = new HashMap<>();

    @Override
    public boolean isAuthentic(Username userid, CharSequence passwd) {
        String pass = users.get(userid.asString());
        if (pass != null) {
            return passwd.toString().equals(pass);
        }
        return false;
    }
    
    public void addUser(Username user, String password) {
        users.put(user.asString(), password);
    }
}

==> james-project-3.9.0-source-release.zip: james-project/mailbox/store/src/main/java/org/apache/james/mailbox/store/FakeAuthenticator.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.mailbox.store;

import java.util.HashMap;
import java.util.Map;
import java.util.Optional;

import org.apache.james.core.Username;
import org.apache.james.mailbox.Authenticator;

public class FakeAuthenticator implements Authenticator {

    private final Map<String, String> users = new HashMap<>();

    @Override
    public Optional<Username> isAuthentic(Username userid, CharSequence passwd) {
        String pass = users.get(userid.asString());
        if (passwd.toString().equals(pass)) {
            return Optional.of(userid);
        }
        return Optional.empty();
    }
    
    public void addUser(Username user, String password) {
        users.put(user.asString(), password);
    }
}
